@@ -30,7 +30,7 @@ setMethod("as.data.frame", "breslow", function(x, row.names = NULL, optional = F
   if (is.null(subjectnames)) 
     subjectnames <- 1:nrow(x@curves)
   if (length(subjectnames) > 1) 
-    col.names <- paste("survival", colnames(x@curves), sep=".")
+    col.names <- paste("survival", subjectnames, sep=".")
   else
     col.names <- "survival"
   out <- as.data.frame(t(x@curves), row.names, optional)
