@@ -21,10 +21,11 @@ setClass("penfit",
 )
 
 # creation method for a penfit object 
-.makepenfit <- function(object, unpenalized, model, lambda1, lambda2, orthogonalizer, weights, formula) {
+.makepenfit <- function(object, unpenalized, model, lambda1, lambda2, fusedl, orthogonalizer, weights, formula) {
   out <- new("penfit")
                                               
-  object$beta <- object$beta / weights
+  if(!fusedl){
+  object$beta <- object$beta / weights}
 
   beta <- object$beta[unpenalized + seq_len(length(object$beta) - unpenalized)]
   gamma <- object$beta[seq_len(unpenalized)] - drop(orthogonalizer %*% beta)
@@ -32,6 +33,7 @@ setClass("penfit",
   out@unpenalized <- gamma
   out@penalized <- beta
 
+
   out@residuals <- object$fit$residuals
   out@fitted <- object$fit$fitted
   out@lin.pred <- object$fit$lp
@@ -53,7 +55,6 @@ setClass("penfit",
   
   out@lambda1 <- lambda1
   out@lambda2 <- lambda2
-  
   out@weights <- weights
   
   out
@@ -115,6 +116,8 @@ setMethod("linear.predictors", "penfit", function(object, ...) {
   object@lin.pred
 })
 
+
+
 # extracts the fitted values
 setMethod("fitted.values", "penfit", function(object, ...) {
   object@fitted
